Admin Dashboard - Baselith-Core

Periodo
Ultimi 30 giorni

## Feedback Totali

0

Ultimi 30 giorni

## Positivi

0

Ultimi 30 giorni

## Negativi

0

Ultimi 30 giorni

## Tasso Positivi

0%

Ultimi 30 giorni

## Clarificazioni

0

Trigger totali

- 0 senza risultati
- 0 nessun rerank disponibile
- 0 contesto insufficiente

## Distribuzione Feedback

## 📝 Feedback Recenti

ID | Domanda | Risposta | Feedback | Conversation ID | Commento | Fonti | Timestamp
--- | --- | --- | --- | --- | --- | --- | ---

## Feedback nel Tempo

## Query più frequenti

Query | Totale | Positivi | Negativi | % Positivi | Ultimo feedback
--- | --- | --- | --- | --- | ---

## Fonti più citate

Fonte | Origine | Totale | Positivi | Negativi | % Positivi
--- | --- | --- | --- | --- | ---

## Query da revisionare (Active Learning)

Query | Totale | Positivi | Negativi | % Positivi | Ultimo feedback
--- | --- | --- | --- | --- | ---

×

### Risposta completa